summaryrefslogtreecommitdiffstats
path: root/tools/lib/h5diff.h
diff options
context:
space:
mode:
authorPeter Cao <xcao@hdfgroup.org>2009-09-11 20:09:34 (GMT)
committerPeter Cao <xcao@hdfgroup.org>2009-09-11 20:09:34 (GMT)
commit5f3a7254c11733038f595f4af4b0ecbbdac2ab2b (patch)
tree4032c779e5a8abf2fbbc8a16b983dba6179b7f05 /tools/lib/h5diff.h
parentf41b8ab87bfc9702f12a3df10911960731556bed (diff)
downloadhdf5-5f3a7254c11733038f595f4af4b0ecbbdac2ab2b.zip
hdf5-5f3a7254c11733038f595f4af4b0ecbbdac2ab2b.tar.gz
hdf5-5f3a7254c11733038f595f4af4b0ecbbdac2ab2b.tar.bz2
[svn-r17466] " Use strict equality as default
" Use "--use-system-epsilon" for system EPSILON " Use "-p" or "-d" for whatever user's choice of epsilon " Use "-p 0" or "-d 0" for strict equality (same as default)
Diffstat (limited to 'tools/lib/h5diff.h')
-rw-r--r--tools/lib/h5diff.h31
1 files changed, 16 insertions, 15 deletions
diff --git a/tools/lib/h5diff.h b/tools/lib/h5diff.h
index e0f2ad0..df264dd 100644
--- a/tools/lib/h5diff.h
+++ b/tools/lib/h5diff.h
@@ -25,21 +25,22 @@
*/
typedef struct {
- int m_quiet; /* quiet mide: no output at all */
- int m_report; /* report mode: print the data */
- int m_verbose; /* verbose mode: print the data, list of objcets, warnings */
- int d; /* delta, absolute value to compare */
- double delta; /* delta value */
- int p; /* relative error to compare*/
- double percent; /* relative error value */
- int n; /* count, compare up to count */
- hsize_t count; /* count value */
- int err_stat; /* an error ocurred (1, error, 0, no error) */
- int cmn_objs; /* do we have common objects */
- int not_cmp; /* are the objects comparable */
- int contents; /* equal contents */
- int do_nans; /* consider Nans while diffing floats */
- int m_list_not_cmp; /* list not comparable messages */
+ int m_quiet; /* quiet mide: no output at all */
+ int m_report; /* report mode: print the data */
+ int m_verbose; /* verbose mode: print the data, list of objcets, warnings */
+ int d; /* delta, absolute value to compare */
+ double delta; /* delta value */
+ int p; /* relative error to compare*/
+ int use_system_epsilon; /* flag to use system epsilon (1 or 0) */
+ double percent; /* relative error value */
+ int n; /* count, compare up to count */
+ hsize_t count; /* count value */
+ int err_stat; /* an error ocurred (1, error, 0, no error) */
+ int cmn_objs; /* do we have common objects */
+ int not_cmp; /* are the objects comparable */
+ int contents; /* equal contents */
+ int do_nans; /* consider Nans while diffing floats */
+ int m_list_not_cmp; /* list not comparable messages */
} diff_opt_t;